@@ -134,6 +134,8 @@ class TestSourceCodeGeneration(unittest.TestCase):
 
     @verify
     def testReturn(self):
+        def test():
+            return foo
         return foo, bar
 
     @verify
@@ -312,3 +314,8 @@ class TestSourceCodeGeneration(unittest.TestCase):
         self.assertEqual(verify_source(
             "'0'\n0"), None)
 
+    @verify
+    def testIndentation(self):
+        for abc in abc:
+            ppp
+            ppp
